Documentation
¶
Index ¶
- func GodelPropsDistPkgInfo(projectDir string) (godelgetter.PkgSrc, error)
- func InstallVersion(projectDir, targetVersion string, cacheValidDuration time.Duration, ...) error
- func NewInstall(dstDirPath string, srcPkg godelgetter.PkgSrc, stdout io.Writer) error
- func Update(projectDirPath string, srcPkg godelgetter.PkgSrc, stdout io.Writer) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GodelPropsDistPkgInfo ¶
func GodelPropsDistPkgInfo(projectDir string) (godelgetter.PkgSrc, error)
GodelPropsDistPkgInfo returns a package that consists of the distribution URL and checksum (if it exists) from the gödel configuration file for the gödel installation in the provided project directory.
func InstallVersion ¶
func InstallVersion(projectDir, targetVersion string, cacheValidDuration time.Duration, newInstall bool, stdout io.Writer) error
InstallVersion installs the specified version of gödel in the provided project directory. If targetVersion is the empty string, the latest version is determined and used.
func NewInstall ¶
NewInstall performs a new installation of gödel in the specified directory using the specified package as the source. Calls "Install" to install the package provided as a parameter. Once the package is installed, the wrapper and settings files are copied from the newly downloaded distribution to the specified path. If there was a previous installation of gödel in the path, it is overwritten by the new file. However, changes in the "var" directory are purely additive -- files that have been added in this directory in the new distribution will be added, but existing files will not be modified or removed.
func Update ¶
Update updates the gödel installation in the specified directory to be the distribution specified by the provided package source. Once the package is installed, the existing wrapper script and its directory are overwritten with the files provided by the package that was downloaded. However, changes in the "godel" directory are purely additive -- files that have been added in this directory in the new distribution will be added, but existing files will not be modified or removed.
Types ¶
This section is empty.